@@ -166,6 +166,9 @@ class TeaCore:
         runtime_option = runtime_option or {}
 
         verify = not runtime_option.get('ignoreSSL', False)
+        if verify:
+            verify = runtime_option.get('ca', True) if runtime_option.get('ca', True) is not None else True
+        cert = runtime_option.get('cert', None)
 
         connect_timeout = runtime_option.get('connectTimeout')
         connect_timeout = connect_timeout if connect_timeout else DEFAULT_CONNECT_TIMEOUT
@@ -207,6 +210,7 @@ class TeaCore:
                 proxies=proxies,
                 timeout=timeout,
                 verify=verify,
+                cert=cert,
             )
         except IOError as e:
             raise RetryError(str(e))
